@@ -22,12 +22,12 @@ LOG = logging.getLogger(__name__)
 
 
 class PingCommand(base.GetCommand):
-    """ Ping a service on a given host """
+    """Ping a service on a given host"""
 
     def get_parser(self, prog_name):
         parser = super(PingCommand, self).get_parser(prog_name)
 
-        parser.add_argument('--service', help="Service Name (e.g. central)",
+        parser.add_argument('--service', help="Service name (e.g. central)",
                             required=True)
         parser.add_argument('--host', help="Hostname", required=True)
 
